#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2022/7/20 1:44 下午
# @Author  : Meng Wang
# @Site    : 
# @File    : __init__.py.py
# @Software: PyCharm
__VER__ = '1.0.0'
__AUTHOR = "Meng Wang @ wmlucas.cn@gmail.com"

